@@ -1,5 +1,3 @@
-library(dplyr)
-svg(tempfile("tmp.svg"))
 test_that("Test for case when output has title, footnote and source", {
   x <- iris[1:2, ] |>
     rtf_title("Title") |>
@@ -21,13 +19,13 @@ test_that("Test the pageby rows are the last rows of a page", {
     rtf_pageby(page_by = "Species", new_page = TRUE, pageby_header = FALSE)
 
   y <- as.data.frame(attributes(as_rtf_pageby(x))) |>
-    group_by(info.id) |>
-    summarise_all(last) |>
-    mutate(row = substr(as.character(info.page), 1, 1))
+    dplyr::group_by(info.id) |>
+    dplyr::summarise_all(dplyr::last) |>
+    dplyr::mutate(row = substr(as.character(info.page), 1, 1))
 
   z <- as.data.frame(table(x$Species)) |>
-    mutate(cu = cumsum(Freq))
-  z <- z |> mutate(cum = cu + as.numeric(rownames(z)))
+    dplyr::mutate(cu = cumsum(Freq))
+  z <- z |> dplyr::mutate(cum = cu + as.numeric(rownames(z)))
 
   expect_equal(y$row, rownames(y))
   expect_equal(y$info.index, z$cum)
@@ -66,8 +64,8 @@ test_that("Test if page_dict attribute is created for tbl", {
 
 test_that("Test for more than one page_by var", {
   x <- iris |>
-    mutate(cat = rep(1:5, 30)) |>
-    arrange(Species, cat) |>
+    dplyr::mutate(cat = rep(1:5, 30)) |>
+    dplyr::arrange(Species, cat) |>
     rtf_page(nrow = 5) |>
     rtf_body() |>
     rtf_pageby(page_by = c("Species", "cat"), new_page = TRUE, pageby_header = TRUE)
@@ -92,8 +90,8 @@ test_that("Test if new_page is FALSE and group_by is NOT NULL", {
 })
 
 test_that("Test whether lines with '-----' were removed correctly", {
-  x <- distinct(iris |> subset(Species != "virginica"), Species, .keep_all = T) |>
-    mutate(Species = ifelse(Species == "setosa", "-----", Species)) |>
+  x <- dplyr::distinct(iris |> subset(Species != "virginica"), Species, .keep_all = TRUE) |>
+    dplyr::mutate(Species = ifelse(Species == "setosa", "-----", Species)) |>
     rtf_colheader("Sepal.Length | Sepal.Width | Petal.Length | Petal.Width",
       col_rel_width = rep(1, 4)
     ) |>
@@ -111,8 +109,8 @@ test_that("Test whether lines with '-----' were removed correctly", {
 
 test_that("Test when using subline_by and page_by together in rtf_body", {
   tbl1 <- iris[c(1:4, 51:54), 3:5] |>
-    mutate(s2 = paste0(Species, 1:2), s3 = s2) |>
-    arrange(Species, s2) |>
+    dplyr::mutate(s2 = paste0(Species, 1:2), s3 = s2) |>
+    dplyr::arrange(Species, s2) |>
     rtf_body(
       subline_by = "s2",
       page_by = "Species"
@@ -125,8 +123,8 @@ test_that("Test when using subline_by and page_by together in rtf_body", {
 
 test_that("Test when using subline_by and page_by with pageby_row = 'first_row' in rtf_body", {
   tbl2 <- iris[c(1:4, 51:54), 3:5] |>
-    mutate(s2 = paste0(Species, 1:2), s3 = s2) |>
-    arrange(Species, s2) |>
+    dplyr::mutate(s2 = paste0(Species, 1:2), s3 = s2) |>
+    dplyr::arrange(Species, s2) |>
     rtf_body(
       subline_by = "s2",
       page_by = "Species",
@@ -136,5 +134,3 @@ test_that("Test when using subline_by and page_by with pageby_row = 'first_row'
 
   expect_snapshot_output(tbl2$body)
 })
-
-dev.off()
